@@ -37,6 +37,8 @@
 #include <QLabel>
 #include <QWizardPage>
 
+#include <QStyleHints>
+
 #include <QDebug>
 
 using namespace UKUI;
@@ -46,6 +48,28 @@ ProxyStyle::ProxyStyle(const QString &key) : QProxyStyle(key == nullptr? "fusion
     auto settings = UKUIStyleSettings::globalInstance();
     m_use_custom_highlight_color = settings->get("useCustomHighlightColor").toBool();
     m_custom_highlight_color = QColor(settings->get("customHighlightColor").toString());
+    m_blink_cursor = settings->get("cursorBlink").toBool();
+    m_blink_cursor_time = settings->get("cursorBlinkTime").toInt();
+    qApp->styleHints()->setCursorFlashTime(m_blink_cursor_time);
+    connect(settings, &QGSettings::changed, this, [=](const QString &key) {
+        if (key == "cursorBlink") {
+            m_blink_cursor = settings->get("cursorBlink").toBool();
+            if (qApp->activeWindow()) {
+                qApp->activeWindow()->update();
+            }
+            if (qApp->activeModalWidget()) {
+                qApp->activeModalWidget()->update();
+            }
+            if (qApp->activePopupWidget()) {
+                qApp->activePopupWidget()->update();
+            }
+        }
+        if (key == "cursorBlinkTime") {
+            m_blink_cursor_time = settings->get("cursorBlinkTime").toInt();
+            qApp->styleHints()->setCursorFlashTime(m_blink_cursor_time);
+        }
+    });
+
     connect(settings, &QGSettings::changed, this, [=](const QString &key) {
         if (key == "useCustomHighlightColor") {
             m_use_custom_highlight_color = settings->get("useCustomHighlightColor").toBool();
@@ -96,6 +120,22 @@ ProxyStyle::ProxyStyle(const QString &key) : QProxyStyle(key == nullptr? "fusion
             break;
         }
     });
+
+    if (QGSettings::isSchemaInstalled("org.ukui.peripherals-mouse")) {
+        QGSettings *settings = new QGSettings("org.ukui.peripherals-mouse");
+        int mouse_double_click_time = settings->get("doubleClick").toInt();
+        if (mouse_double_click_time != qApp->doubleClickInterval()) {
+            qApp->setDoubleClickInterval(mouse_double_click_time);
+        }
+        connect(settings, &QGSettings::changed, qApp, [=] (const QString &key) {
+            if (key == "doubleClick") {
+                int mouse_double_click_time = settings->get("doubleClick").toInt();
+                if (mouse_double_click_time != qApp->doubleClickInterval()) {
+                    qApp->setDoubleClickInterval(mouse_double_click_time);
+                }
+            }
+        });
+    }
 }
 
 bool ProxyStyle::eventFilter(QObject *obj, QEvent *e)
@@ -115,6 +155,9 @@ int ProxyStyle::styleHint(StyleHint hint, const QStyleOption *option, const QWid
     case QStyle::SH_Menu_Scrollable: {
         return 1;
     }
+    case QStyle::SH_BlinkCursorWhenTextSelected: {
+        return m_blink_cursor;
+    }
     default:
         return QProxyStyle::styleHint(hint, option, widget, returnData);
     }
@@ -129,7 +172,6 @@ void ProxyStyle::polish(QWidget *widget)
 
     if(!widget)
         return;
-
     if (qAppName() == "ukui-menu" && !widget->inherits("QMenu")) {
         return;
     }
