@@ -29,6 +29,7 @@ class TabWidgetAnimationHelper;
 class ScrollBarAnimationHelper;
 class ButtonAnimationHelper;
 class BoxAnimationHelper;
+class ShadowHelper;
 
 class QStyleOptionViewItem;
 
@@ -100,6 +101,8 @@ public:
     QRect subElementRect(SubElement element,
                                  const QStyleOption *option,
                                  const QWidget *widget = nullptr) const;
+    QSize sizeFromContents(ContentsType ct, const QStyleOption *option,
+                           const QSize &size, const QWidget *widget) const;
 
 protected:
     const QStringList useDefaultPalette() const;
@@ -119,6 +122,7 @@ private:
     ScrollBarAnimationHelper *m_scrollbar_animation_helper;
     ButtonAnimationHelper*  m_button_animation_helper;
     BoxAnimationHelper* m_combobox_animation_helper;
+    ShadowHelper *m_shadow_helper;
 
 
     bool m_use_dark_palette = false;
